from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, awgn_state: bool, path=repcap.Path.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:AWGN:[RF<CH>]:STATe \n
		Snippet: driver.source.bb.gnss.awgn.rf.state.set(awgn_state = False, path = repcap.Path.Default) \n
		Activates/deactivates the generation of an AWGN signal. The interferer (AWGN or CW interferer, depending on the selected
		mode) is generated after the generator is activated. \n
			:param awgn_state: 1| ON| 0| OFF
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
		"""
		param = Conversions.bool_to_str(awgn_state)
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:AWGN:RF{path_cmd_val}:STATe {param}')

	def get(self, path=repcap.Path.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:AWGN:[RF<CH>]:STATe \n
		Snippet: value: bool = driver.source.bb.gnss.awgn.rf.state.get(path = repcap.Path.Default) \n
		Activates/deactivates the generation of an AWGN signal. The interferer (AWGN or CW interferer, depending on the selected
		mode) is generated after the generator is activated. \n
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
			:return: awgn_state: 1| ON| 0| OFF"""
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:AWGN:RF{path_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)
